@@ -25,8 +25,10 @@
 #' @export
 #'
 newCdmTable <- function(table, src, name) {
-  assertClass(src, class = "cdm_source")
-  assertCharacter(name, length = 1, na = TRUE)
+  assertClass(src, class = "cdm_source",
+              msg = "`src` does not have the class: cdm_source")
+  assertCharacter(name, length = 1, na = TRUE,
+                  msg = "`name` is not a character vector of length 1")
   table <- structure(.Data = table, tbl_source = src, tbl_name = name) |>
     addClass("cdm_table")
   if (any(colnames(table) != tolower(colnames(table)))) {
@@ -58,7 +60,7 @@ newCdmTable <- function(table, src, name) {
 #'     "observation_period" = tibble(
 #'       observation_period_id = 1:3, person_id = 1:3,
 #'       observation_period_start_date = as.Date("2000-01-01"),
-#'       observation_period_end_date = as.Date("2025-12-31"),
+#'       observation_period_end_date = as.Date("2023-12-31"),
 #'       period_type_concept_id = 0
 #'     )
 #'   ),
@@ -94,7 +96,7 @@ cdmReference <- function(table) {
 #'     "observation_period" = tibble(
 #'       observation_period_id = 1:3, person_id = 1:3,
 #'       observation_period_start_date = as.Date("2000-01-01"),
-#'       observation_period_end_date = as.Date("2025-12-31"),
+#'       observation_period_end_date = as.Date("2023-12-31"),
 #'       period_type_concept_id = 0
 #'     )
 #'   ),
@@ -104,7 +106,8 @@ cdmReference <- function(table) {
 #' tableName(cdm$person)
 #' }
 tableName <- function(table) {
-  assertClass(table, "cdm_table")
+  assertClass(table, "cdm_table",
+              msg = "`table` does not have the class: cdm_table")
   attr(table, "tbl_name")
 }
 
@@ -130,7 +133,7 @@ tableName <- function(table) {
 #'     "observation_period" = tibble(
 #'       observation_period_id = 1:3, person_id = 1:3,
 #'       observation_period_start_date = as.Date("2000-01-01"),
-#'       observation_period_end_date = as.Date("2025-12-31"),
+#'       observation_period_end_date = as.Date("2023-12-31"),
 #'       period_type_concept_id = 0
 #'     )
 #'   ),
@@ -140,14 +143,20 @@ tableName <- function(table) {
 #' tableSource(cdm$person)
 #' }
 tableSource <- function(table) {
-  assertClass(table, "cdm_table")
+  assertClass(table, "cdm_table",
+              msg = "`table` does not have the class: cdm_table")
   attr(table, "tbl_source")
 }
 
 #' @export
 #' @importFrom dplyr collect
 collect.cdm_table <- function(x, ...) {
-  x <- removeClass(x, "cdm_table") |> dplyr::collect()
+  x <- removeClass(x, "cdm_table")
+  if (any(colnames(x) != tolower(colnames(x)))) {
+    # TO CHANGE TO ERROR IN NEW RELEASE
+    cli::cli_warn(c("!" = "A cdm_table must have lowercase column names."))
+  }
+  x <- x |> dplyr::collect()
   attr(x, "tbl_name") <- NULL
   attr(x, "tbl_source") <- NULL
   attr(x, "cdm_reference") <- NULL
