@@ -36,7 +36,7 @@
 #' observation_period <- tibble(
 #'   observation_period_id = 1, person_id = 1,
 #'   observation_period_start_date = as.Date("2000-01-01"),
-#'   observation_period_end_date = as.Date("2025-12-31"),
+#'   observation_period_end_date = as.Date("2023-12-31"),
 #'   period_type_concept_id = 0
 #' )
 #' cohort <- tibble(
@@ -139,7 +139,7 @@ updateAttrition <- function(cohort, cohortId, reason) {
           "reason_id" = max(.data$reason_id), .groups = "drop"
         ) |>
         dplyr::mutate(
-          "reason_id" = .data$reason_id + 1, "reason" = .env$reason
+          "reason_id" = .data$reason_id + 1L, "reason" = .env$reason
         ),
       by = "cohort_definition_id"
     ) |>
