@@ -5,39 +5,39 @@ test_that("bind no class", {
 
 test_that("bind a cohort_table", {
   cohort1 <- dplyr::tibble(
-    cohort_definition_id = 1,
-    subject_id = 1:3,
+    cohort_definition_id = 1 |> as.integer(),
+    subject_id = 1:3 |> as.integer(),
     cohort_start_date = as.Date("2010-01-01"),
     cohort_end_date = as.Date("2010-01-05")
   )
   cohort2 <- dplyr::tibble(
-    cohort_definition_id = c(2, 2, 3, 3, 3),
-    subject_id = c(1, 2, 3, 1, 2),
+    cohort_definition_id = c(2, 2, 3, 3, 3) |> as.integer(),
+    subject_id = c(1, 2, 3, 1, 2) |> as.integer(),
     cohort_start_date = as.Date("2010-01-01"),
     cohort_end_date = as.Date("2010-01-05")
   )
   cohort3 <- dplyr::tibble(
-    cohort_definition_id = 1:5,
-    subject_id = c(1, 2, 3, 1, 2),
+    cohort_definition_id = 1:5 |> as.integer(),
+    subject_id = c(1, 2, 3, 1, 2) |> as.integer(),
     cohort_start_date = as.Date("2010-01-01"),
     cohort_end_date = as.Date("2010-01-05")
   )
   cohort4 <- cohort3
   attr(cohort4, "cohort_set") <- dplyr::tibble(
-    cohort_definition_id = 1:5,
+    cohort_definition_id = 1:5 |> as.integer(),
     cohort_name = c("first_cohort", "second_cohort", "third_cohort", "fourth_cohort", "fifth_cohort")
   )
   cdm <- cdmFromTables(
     tables = list(
       "person" = dplyr::tibble(
-        person_id = c(1, 2, 3), gender_concept_id = 0, year_of_birth = 1990,
-        race_concept_id = 0, ethnicity_concept_id = 0
+        person_id = c(1L, 2L, 3L), gender_concept_id = 0L, year_of_birth = 1990L,
+        race_concept_id = 0L, ethnicity_concept_id = 0L
       ),
       "observation_period" = dplyr::tibble(
-        observation_period_id = 1:3, person_id = 1:3,
+        observation_period_id = c(1L, 2L, 3L), person_id = c(1L, 2L, 3L),
         observation_period_start_date = as.Date("2000-01-01"),
-        observation_period_end_date = as.Date("2025-12-31"),
-        period_type_concept_id = 0
+        observation_period_end_date = as.Date("2023-12-31"),
+        period_type_concept_id = 0L
       )
     ),
     cdmName = "mock",
@@ -83,28 +83,28 @@ test_that("bind a cohort_table", {
   expect_equal(attrition(newcdm$new_cohort) |> nrow(), 8)
 
   cohort1 <- dplyr::tibble(
-    cohort_definition_id = 1,
-    subject_id = 1:3,
+    cohort_definition_id = 1 |> as.integer(),
+    subject_id = 1:3 |> as.integer(),
     cohort_start_date = as.Date("2010-01-01"),
     cohort_end_date = as.Date("2010-01-05"),
     extra_column1 = 1
   )
   cohort2 <- dplyr::tibble(
-    cohort_definition_id = c(2, 2, 3, 3, 3),
-    subject_id = c(1, 2, 3, 1, 2),
+    cohort_definition_id = c(2, 2, 3, 3, 3) |> as.integer(),
+    subject_id = c(1, 2, 3, 1, 2) |> as.integer(),
     cohort_start_date = as.Date("2010-01-01"),
     cohort_end_date = as.Date("2010-01-05"),
     extra_column2 = TRUE,
     extra_column3 = "fjhhl"
   )
   cohort3 <- dplyr::tibble(
-    cohort_definition_id = 1:5,
-    subject_id = c(1, 2, 3, 1, 2),
+    cohort_definition_id = 1:5 |> as.integer(),
+    subject_id = c(1, 2, 3, 1, 2) |> as.integer(),
     cohort_start_date = as.Date("2010-01-01"),
     cohort_end_date = as.Date("2010-01-05")
   )
   attr(cohort3, "cohort_set") <- dplyr::tibble(
-    cohort_definition_id = 1:5,
+    cohort_definition_id = as.integer(1:5),
     cohort_name = c(
       "first_cohort", "second_cohort", "third_cohort", "fourth_cohort",
       "fifth_cohort"
@@ -113,14 +113,14 @@ test_that("bind a cohort_table", {
   cdm <- cdmFromTables(
     tables = list(
       "person" = dplyr::tibble(
-        person_id = c(1, 2, 3), gender_concept_id = 0, year_of_birth = 1990,
-        race_concept_id = 0, ethnicity_concept_id = 0
+        person_id = c(1L, 2L, 3L), gender_concept_id = 0L, year_of_birth = 1990L,
+        race_concept_id = 0L, ethnicity_concept_id = 0L
       ),
       "observation_period" = dplyr::tibble(
-        observation_period_id = 1:3, person_id = 1:3,
+        observation_period_id = c(1L, 2L, 3L), person_id = c(1L, 2L, 3L),
         observation_period_start_date = as.Date("2000-01-01"),
-        observation_period_end_date = as.Date("2025-12-31"),
-        period_type_concept_id = 0
+        observation_period_end_date = as.Date("2023-12-31"),
+        period_type_concept_id = 0L
       )
     ),
     cdmName = "mock",
@@ -199,7 +199,7 @@ test_that("bind summarised_result", {
 
   # if we bind the same summarised_result we get an error because number of
   # subjects is repeated
-  expect_error(new3 <- bind(res2, res2))
+  expect_equal(bind(res2, res2), res2)
 
   # repeated settings
   expect_no_error(new4 <- bind(res3, res5))
@@ -214,4 +214,37 @@ test_that("bind summarised_result", {
   expect_identical(
     new5 |> settings() |> dplyr::pull("result_id") |> unique(), c(1L, 2L)
   )
+
+  # empty results with no settings
+  expect_identical(bind(emptySummarisedResult()),
+                   emptySummarisedResult())
+  expect_identical(bind(emptySummarisedResult(),
+                        emptySummarisedResult()),
+                   emptySummarisedResult())
+
+  # empty results with settings
+  expect_identical(bind(emptySummarisedResult(settings = dplyr::tibble(result_id = 1L,
+                                                                       a = "a"))),
+                   emptySummarisedResult(settings = dplyr::tibble(result_id = 1L,
+                                                                  a = "a")))
+  expect_identical(bind(emptySummarisedResult(settings = dplyr::tibble(result_id = 1L,
+                                                                       a = "a")),
+                        emptySummarisedResult(settings = dplyr::tibble(result_id = 2L,
+                                                                       a = "b"))),
+                   emptySummarisedResult(settings = dplyr::tibble(result_id = c(1L, 2L),
+                                                                  a = c("a", "b"))))
+
+  # empty elements
+  expect_no_error(bind(NULL))
+  expect_no_error(bind(res3, emptySummarisedResult()))
+  expect_no_error(bind(res3, NULL))
+  expect_no_error(bind(NULL, res3))
+  expect_no_error(bind(list(NULL, res3)))
+  expect_no_error(bind(list(res3, NULL)))
+  expect_no_error(bind(NULL, list(NULL, res3)))
+  expect_no_error(bind(NULL, list(res3, NULL)))
+  # do we want this to work?
+  expect_error(bind(list(NULL, res3), NULL))
+  expect_error(bind(list(res3, NULL), NULL))
+
 })
