@@ -1,13 +1,13 @@
 test_that("summary a cdm reference", {
   person <- dplyr::tibble(
-    person_id = 1, gender_concept_id = 0, year_of_birth = 1990,
-    race_concept_id = 0, ethnicity_concept_id = 0
+    person_id = 1L, gender_concept_id = 0L, year_of_birth = 1990L,
+    race_concept_id = 0L, ethnicity_concept_id = 0L
   )
   observation_period <- dplyr::tibble(
-    observation_period_id = 1:2, person_id = 1,
-    observation_period_start_date = as.Date(c("2000-01-01", "2031-01-01")),
-    observation_period_end_date = as.Date(c("2025-12-31", "2032-01-01")),
-    period_type_concept_id = 0
+    observation_period_id = c(1L, 2L), person_id = 1L,
+    observation_period_start_date = as.Date(c("2000-01-01", "2021-01-01")),
+    observation_period_end_date = as.Date(c("2019-12-31", "2022-01-01")),
+    period_type_concept_id = 0L
   )
   cdm <- cdmFromTables(
     tables = list("person" = person, "observation_period" = observation_period),
@@ -61,7 +61,7 @@ test_that("summary a cdm reference", {
     ),
     value = c(
       as.character(Sys.Date()), "1", "2", rep(NA_character_, 7),
-      "2000-01-01", "2032-01-01"
+      "2000-01-01", "2022-01-01"
     )
   )
   for (k in seq_len(nrow(expt))) {
@@ -87,18 +87,18 @@ test_that("summary a cdm reference", {
 
 test_that("summary a generated cohort set", {
   person <- dplyr::tibble(
-    person_id = 1, gender_concept_id = 0, year_of_birth = 1990,
-    race_concept_id = 0, ethnicity_concept_id = 0
+    person_id = 1L, gender_concept_id = 0L, year_of_birth = 1990L,
+    race_concept_id = 0L, ethnicity_concept_id = 0L
   )
   observation_period <- dplyr::tibble(
-    observation_period_id = 1, person_id = 1,
+    observation_period_id = 1L, person_id = 1L,
     observation_period_start_date = as.Date("2000-01-01"),
-    observation_period_end_date = as.Date("2025-12-31"),
-    period_type_concept_id = 0
+    observation_period_end_date = as.Date("2022-12-31"),
+    period_type_concept_id = 0L
   )
   cohort <- dplyr::tibble(
-    cohort_definition_id = 1,
-    subject_id = 1,
+    cohort_definition_id = 1L,
+    subject_id = 1L,
     cohort_start_date = as.Date("2020-01-01"),
     cohort_end_date = as.Date("2020-01-01")
   )
@@ -111,7 +111,7 @@ test_that("summary a generated cohort set", {
   expect_no_error(summary(cdm$cohort2))
   cdm$cohort2 <- cdm$cohort2 |>
     newCohortTable(cohortSetRef = dplyr::tibble(
-      cohort_definition_id = 1, cohort_name = "my_cohort", parameter = 1
+      cohort_definition_id = 1L, cohort_name = "my_cohort", parameter = 1
     ))
   expect_no_error(cdm <- bind(cdm$cohort1, cdm$cohort2, name = "cohort3"))
   expect_no_error(summary(cdm$cohort3))
