@@ -1,17 +1,17 @@
 test_that("multiplication works", {
   person <- dplyr::tibble(
-    person_id = 1, gender_concept_id = 0, year_of_birth = 1990,
-    race_concept_id = 0, ethnicity_concept_id = 0
+    person_id = 1L, gender_concept_id = 0L, year_of_birth = 1990L,
+    race_concept_id = 0L, ethnicity_concept_id = 0L
   )
   observation_period <- dplyr::tibble(
-    observation_period_id = 1, person_id = 1,
+    observation_period_id = 1L, person_id = 1L,
     observation_period_start_date = as.Date("2000-01-01"),
-    observation_period_end_date = as.Date("2025-12-31"),
-    period_type_concept_id = 0
+    observation_period_end_date = as.Date("2023-12-31"),
+    period_type_concept_id = 0L
   )
   cohort <- dplyr::tibble(
-    cohort_definition_id = c(1, 1, 1, 2),
-    subject_id = 1,
+    cohort_definition_id = c(1L, 1L, 1L, 2L),
+    subject_id = 1L,
     cohort_start_date = as.Date(c("2020-01-01", "2021-01-01", "2022-01-01", "2022-01-01")),
     cohort_end_date = as.Date(c("2020-01-01", "2021-01-01", "2022-01-01", "2022-01-01")),
   )
@@ -42,13 +42,13 @@ test_that("multiplication works", {
   expect_equal(
     att |> dplyr::as_tibble(),
     dplyr::tibble(
-      cohort_definition_id = c(1, 1, 2, 2),
-      number_records = c(3, 2, 1, 0),
-      number_subjects = c(1, 1, 1, 0),
-      reason_id = c(1, 2, 1, 2),
+      cohort_definition_id = c(1, 1, 2, 2) |> as.integer(),
+      number_records = c(3, 2, 1, 0) |> as.integer(),
+      number_subjects = c(1, 1, 1, 0) |> as.integer(),
+      reason_id = c(1, 2, 1, 2) |> as.integer(),
       reason = rep(c("Initial qualifying events", "Before 2021-06-01"), 2),
-      excluded_records = c(0, 1, 0, 1),
-      excluded_subjects = c(0, 0, 0, 1)
+      excluded_records = c(0, 1, 0, 1) |> as.integer(),
+      excluded_subjects = c(0, 0, 0, 1) |> as.integer()
     )
   )
 
@@ -69,13 +69,13 @@ test_that("multiplication works", {
   expect_equal(
     att |> dplyr::as_tibble(),
     dplyr::tibble(
-      cohort_definition_id = c(1, 1, 1, 2, 2, 2),
-      number_records = c(3, 2, 1, 1, 0, 0),
-      number_subjects = c(1, 1, 1, 1, 0, 0),
-      reason_id = c(1, 2, 3, 1, 2, 3),
+      cohort_definition_id = c(1, 1, 1, 2, 2, 2) |> as.integer(),
+      number_records = c(3, 2, 1, 1, 0, 0) |> as.integer(),
+      number_subjects = c(1, 1, 1, 1, 0, 0) |> as.integer(),
+      reason_id = c(1, 2, 3, 1, 2, 3) |> as.integer(),
       reason = rep(c("Initial qualifying events", "Before 2021-06-01", "First record"), 2),
-      excluded_records = c(0, 1, 1, 0, 1, 0),
-      excluded_subjects = c(0, 0, 0, 0, 1, 0)
+      excluded_records = c(0, 1, 1, 0, 1, 0) |> as.integer(),
+      excluded_subjects = c(0, 0, 0, 0, 1, 0) |> as.integer()
     )
   )
 
@@ -105,13 +105,13 @@ test_that("multiplication works", {
   expect_equal(
     att |> dplyr::as_tibble(),
     dplyr::tibble(
-      cohort_definition_id = c(1, 1, 2),
-      number_records = c(3, 2, 1),
-      number_subjects = c(1, 1, 1),
-      reason_id = c(1, 2, 1),
+      cohort_definition_id = c(1, 1, 2) |> as.integer(),
+      number_records = c(3, 2, 1) |> as.integer(),
+      number_subjects = c(1, 1, 1) |> as.integer(),
+      reason_id = c(1, 2, 1) |> as.integer(),
       reason = c("Initial qualifying events", "Before june 2021", "Initial qualifying events"),
-      excluded_records = c(0, 1, 0),
-      excluded_subjects = c(0, 0, 0)
+      excluded_records = c(0, 1, 0) |> as.integer(),
+      excluded_subjects = c(0, 0, 0) |> as.integer()
     )
   )
 
@@ -132,16 +132,16 @@ test_that("multiplication works", {
   expect_equal(
     att |> dplyr::as_tibble(),
     dplyr::tibble(
-      cohort_definition_id = c(1, 1, 1, 2, 2),
-      number_records = c(3, 2, 1, 1, 1),
-      number_subjects = c(1, 1, 1, 1, 1),
-      reason_id = c(1, 2, 3, 1, 2),
+      cohort_definition_id = c(1, 1, 1, 2, 2) |> as.integer(),
+      number_records = c(3, 2, 1, 1, 1) |> as.integer(),
+      number_subjects = c(1, 1, 1, 1, 1) |> as.integer(),
+      reason_id = c(1, 2, 3, 1, 2) |> as.integer(),
       reason = c(
         "Initial qualifying events", "Before june 2021", "First record",
         "Initial qualifying events", "First record"
       ),
-      excluded_records = c(0, 1, 1, 0, 0),
-      excluded_subjects = c(0, 0, 0, 0, 0)
+      excluded_records = c(0, 1, 1, 0, 0) |> as.integer(),
+      excluded_subjects = c(0, 0, 0, 0, 0) |> as.integer()
     )
   )
 
